// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
//
// See the LICENSE.txt file for license information. Please report all
// issues on https://gitlab.onelab.info/getdp/getdp/issues.

#ifndef GENERATE_NETWORK_H
#define GENERATE_NETWORK_H

#include "ProData.h"

struct ConstraintActive * Generate_Network(char *Name, List_T * ConstraintPerRegion_L);

#endif
